@@ -13,15 +13,15 @@
 
 import logging
 import warnings
-from collections import abc
+from collections import namedtuple
 from io import BytesIO
 from json import dumps
+from typing import List, Union, Optional
 
 from coreapi.exceptions import ErrorMessage
 from version_utils import rpm
 
 from adcm_client.base import (
-    ActionHasIssues,
     ADCMApiError,
     BaseAPIListObject,
     BaseAPIObject,
@@ -35,14 +35,21 @@ from adcm_client.base import (
     allure_attach,
     legacy_server_implementaion,
     EndPoint,
+    NoSuchEndpointOrAccessIsDenied,
 )
 from adcm_client.util import stream
+from adcm_client.util.config import update
 from adcm_client.wrappers.api import ADCMApiWrapper
 
 # Init logger
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.DEBUG)
 
+Me = namedtuple(
+    'Me',
+    ('id', 'username', 'first_name', 'last_name', 'email', 'is_superuser', 'password', 'profile'),
+)
+
 
 class NoCredentionsProvided(Exception):
     """There is no user/password provided. It was not passed as init parameters
@@ -316,6 +323,29 @@ class HostPrototypeList(BaseAPIListObject):
 ##################################################
 #           B A S E  O B J E C T
 ##################################################
+
+
+def _config_set_diff(object_with_config, data: dict, attach_to_allure: bool = True) -> dict:
+    """
+    General method to use when config should be updated without passing the full config.
+
+    :param object_with_config: Object with methods `config(..., full: bool) -> dict`
+                               and `config_set(data, attach_to_allure, ...) -> dict`
+    :param data: Dictionary with new config fields
+                 (may or may not contain "config" and "attr" fields)
+    :param attach_to_allure: Flag to decide whether attach
+                             changed fields and original config or not
+    """
+    if attach_to_allure:
+        allure_attach_json(data, name="Changed fields")
+    if "attr" not in data:
+        data = {"config": {**data.get("config", data)}, "attr": {}}
+    config = object_with_config.config(full=True)
+    if attach_to_allure:
+        allure_attach_json(config, name="Original config")
+    return object_with_config.config_set(update(config, data), attach_to_allure=attach_to_allure)
+
+
 class _BaseObject(BaseAPIObject):
     """
     Base class 'BaseObject' for adcm_client objects
@@ -394,25 +424,7 @@ class _BaseObject(BaseAPIObject):
     @allure_step("Save config")
     def config_set_diff(self, data, attach_to_allure=True):
         """Save the difference between old and new config in history"""
-
-        def update(d, u):
-            """If the old and new values are dictionaries, we try to update, otherwise we replace"""
-            for key, value in u.items():
-                if isinstance(value, abc.Mapping) and key in d and isinstance(d[key], abc.Mapping):
-                    d[key] = update(d[key], value)
-                    continue
-                d[key] = value
-            return d
-
-        # this check is incomplete, cases of presence of keys "config" and "attr" in config
-        # are not considered
-        if attach_to_allure:
-            allure_attach_json(data, name="Changed fields")
-        is_full = "config" in data and "attr" in data
-        config = self.config(full=is_full)
-        if attach_to_allure:
-            allure_attach_json(config, name="Original config")
-        return self.config_set(update(config, data), attach_to_allure=attach_to_allure)
+        return _config_set_diff(self, data, attach_to_allure)
 
     def config_prototype(self):
         return self.prototype().config
@@ -454,6 +466,7 @@ class Provider(_BaseObject):
     name = None
     description = None
     bundle_id = None
+    before_upgrade = None
 
     def __repr__(self):
         return f"<Provider {self.name} at {id(self)}>"
@@ -496,8 +509,11 @@ class ProviderList(BaseAPIListObject):
 @allure_step('Create provider {name}')
 def new_provider(api, **args) -> "Provider":
     """Create new 'Provider' object"""
-    p = api.objects.provider.create(**strip_none_keys(args))
-    return Provider(api, provider_id=p['id'])
+    try:
+        provider = api.objects.provider.create(**strip_none_keys(args))
+    except AttributeError as error:
+        raise NoSuchEndpointOrAccessIsDenied from error
+    return Provider(api, provider_id=provider['id'])
 
 
 ##################################################
@@ -517,6 +533,7 @@ class Cluster(_BaseObject):
     status = None
     edition = None
     license = None
+    before_upgrade = None
 
     def __repr__(self):
         return f"<Cluster {self.name} from bundle - {self.bundle_id} at {id(self)}>"
@@ -525,7 +542,7 @@ class Cluster(_BaseObject):
         """Return 'ClusterPrototype' object as its prototype"""
         return self._parent_obj(ClusterPrototype)
 
-    def bind(self, target):
+    def _bind_old(self, target):
         """Check target type. If it is cluster or service - provide matching endpoint"""
         if isinstance(target, Cluster):
             self._subcall("bind", "create", export_cluster_id=target.cluster_id)
@@ -539,10 +556,29 @@ class Cluster(_BaseObject):
         else:
             raise NotImplementedError
 
-    def bind_list(self, paging=None):
+    def _bind_list_old(self, paging=None):
         """Provide endpoint to bind/list"""
         return self._subcall("bind", "list")
 
+    @legacy_server_implementaion(_bind_old, '2022.02.1.00')
+    def bind(self, target) -> "Bind":
+        """Create new Bind object and return it"""
+        if isinstance(target, Cluster):
+            self._subcall("bind", "create", export_cluster_id=target.cluster_id)
+        elif isinstance(target, Service):
+            self._subcall(
+                "bind",
+                "create",
+                export_cluster_id=target.cluster_id,
+                export_service_id=target.service_id,
+            )
+        return self._subobject(Bind)
+
+    @legacy_server_implementaion(_bind_list_old, '2022.02.1.00')
+    def bind_list(self, paging=None, **kwargs) -> "BindList":
+        """Return list of 'Bind' objects"""
+        return self._subobject(BindList, paging=paging, **kwargs)
+
     def bundle(self) -> "Bundle":
         """Return 'Bundle' object from Cluster prototype"""
         proto = self.prototype()
@@ -659,8 +695,11 @@ class ClusterList(BaseAPIListObject):
 @allure_step('Create cluster {name}')
 def new_cluster(api: ADCMApiWrapper, **args) -> "Cluster":
     """Create new 'Cluster' object"""
-    c = api.objects.cluster.create(**strip_none_keys(args))
-    return Cluster(api, cluster_id=c['id'])
+    try:
+        cluster = api.objects.cluster.create(**strip_none_keys(args))
+    except AttributeError as error:
+        raise NoSuchEndpointOrAccessIsDenied from error
+    return Cluster(api, cluster_id=cluster['id'])
 
 
 ##################################################
@@ -687,11 +726,25 @@ class Upgrade(BaseAPIObject):
     state_available = None
     state_on_success = None
     from_edition = None
+    ui_options = None
+    config = None
 
-    def do(self, **args):
-        """Do upgrade and provide do/create endpoint"""
+    def do(self, **args) -> Optional['Task']:
+        """
+        Do upgrade and provide do/create endpoint.
+        Returns a task if an action was fired on the upgrade, or None otherwise
+
+        :param args: config - configuration for action
+        :type args: dict
+        :return: task
+        :rtype: Optional[Task]
+        """
         with allure_step(f"Do upgrade {self.name}"):
-            self._subcall("do", "create", **args)
+            data = self._subcall("do", "create", **args)
+        task = None
+        if data.get('task_id') is not None:
+            task = Task(self._api, task_id=data['task_id'])
+        return task
 
 
 class UpgradeList(BaseAPIListObject):
@@ -701,6 +754,40 @@ class UpgradeList(BaseAPIListObject):
     _ENTRY_CLASS = Upgrade
 
 
+##################################################
+#                B I N D
+##################################################
+
+
+class Bind(BaseAPIObject):
+    """The 'Bind' object from the API"""
+
+    IDNAME = "bind_id"
+    PATH = None
+    SUBPATH = ["bind"]
+
+    id = None
+    bind_id = None
+    export_cluster_id = None
+    export_cluster_name = None
+    export_cluster_prototype_name = None
+    export_service_id = None
+    export_service_name = None
+    import_service_id = None
+    import_service_name = None
+
+    def delete(self):
+        with allure_step(f"Remove bind {self.bind_id}"):
+            self._subcall("delete", bind_id=self.id)
+
+
+class BindList(BaseAPIListObject):
+    """List of 'Bind' objects from the API"""
+
+    SUBPATH = ["bind"]
+    _ENTRY_CLASS = Bind
+
+
 ##################################################
 #           S E R V I C E S
 ##################################################
@@ -738,7 +825,7 @@ class Service(_BaseObject):
     def __repr__(self):
         return f"<Service {self.name} form cluster - {self.cluster_id} at {id(self)}>"
 
-    def bind(self, target):
+    def _bind_old(self, target):
         """Check target type. If it is cluster or service - provide matching endpoint"""
         if isinstance(target, Cluster):
             self._subcall("bind", "create", export_cluster_id=target.cluster_id)
@@ -752,6 +839,29 @@ class Service(_BaseObject):
         else:
             raise NotImplementedError
 
+    def _bind_list_old(self, paging=None):
+        """Provide endpoint bind/list"""
+        return self._subcall("bind", "list")
+
+    @legacy_server_implementaion(_bind_old, '2022.02.1.00')
+    def bind(self, target) -> "Bind":
+        """Create new Bind object and return it"""
+        if isinstance(target, Cluster):
+            self._subcall("bind", "create", export_cluster_id=target.cluster_id)
+        elif isinstance(target, Service):
+            self._subcall(
+                "bind",
+                "create",
+                export_cluster_id=target.cluster_id,
+                export_service_id=target.service_id,
+            )
+        return self._subobject(Bind)
+
+    @legacy_server_implementaion(_bind_list_old, '2022.02.1.00')
+    def bind_list(self, paging=None, **kwargs) -> "BindList":
+        """Return list of 'Bind' objects"""
+        return self._subobject(BindList, paging=paging, **kwargs)
+
     def prototype(self) -> "ServicePrototype":
         """Return new 'ServicePrototype' object"""
         return ServicePrototype(self._api, id=self.prototype_id)
@@ -764,10 +874,6 @@ class Service(_BaseObject):
         """Provide endpoint to import/list"""
         return self._subcall("import", "list")
 
-    def bind_list(self, paging=None):
-        """Provide endpoint bind/list"""
-        return self._subcall("bind", "list")
-
     def _component_old(self, **args) -> "Component":
         """Return 'Component' object"""
         return self._subobject(Component, **args)
@@ -921,6 +1027,11 @@ class Host(_BaseObject):
     description = None
     bundle_id = None
     status = None
+    maintenance_mode: str = None
+
+    def maintenance_mode_set(self, value: str) -> None:
+        self._api.objects.host.partial_update(host_id=self.id, maintenance_mode=value)
+        self.reread()
 
     def __repr__(self):
         return f"<Host {self.fqdn} form provider - {self.provider_id} at {id(self)}>"
@@ -960,8 +1071,11 @@ class HostList(BaseAPIListObject):
 @allure_step('Create host {fqdn}')
 def new_host(api, **args) -> "Host":
     """Create new 'Host' object and return it"""
-    h = api.objects.provider.host.create(**args)
-    return Host(api, host_id=h['id'])
+    try:
+        host = api.objects.provider.host.create(**args)
+    except AttributeError as error:
+        raise NoSuchEndpointOrAccessIsDenied from error
+    return Host(api, host_id=host['id'])
 
 
 ##################################################
@@ -999,6 +1113,7 @@ class Action(BaseAPIObject):
     allow_to_terminate = None
     partial_execution = None
     host_action = None
+    disabling_cause = None
 
     def __repr__(self):
         return f"<Action {self.name} at {id(self)}>"
@@ -1067,14 +1182,7 @@ class Action(BaseAPIObject):
                     f"argument 'verbose'. It will be skipped"
                 )
                 args.pop('verbose')
-            try:
-                data = self._subcall("run", "create", **args)
-            except ErrorMessage as error:
-                if getattr(error.error, 'title', '') == '409 Conflict' and 'has issues' in getattr(
-                    error.error, '_data', {}
-                ).get('desc', ''):
-                    raise ActionHasIssues from error
-                raise error
+            data = self._subcall("run", "create", **args)
             return Task(self._api, task_id=data["id"])
 
 
@@ -1345,25 +1453,9 @@ class GroupConfig(BaseAPIObject):
         return current_config["config"]
 
     @allure_step("Save group config")
-    def config_set_diff(self, data, attach_to_allure=True):
+    def config_set_diff(self, data: dict, attach_to_allure: bool = True) -> dict:
         """Partial config update"""
-
-        def update(d, u):
-            """If the old and new values are dictionaries, we try to update, otherwise we replace"""
-            for key, value in u.items():
-                if isinstance(value, abc.Mapping) and key in d and isinstance(d[key], abc.Mapping):
-                    d[key] = update(d[key], value)
-                    continue
-                d[key] = value
-            return d
-
-        if attach_to_allure:
-            allure_attach_json(data, name="Changed fields")
-        is_full = "config" in data and "attr" in data
-        config = self.config(full=is_full)
-        if attach_to_allure:
-            allure_attach_json(config, name="Original config")
-        return self.config_set(update(config, data), attach_to_allure=attach_to_allure)
+        return _config_set_diff(self, data, attach_to_allure)
 
     def host_candidate(self, paging=None, **kwargs) -> "HostList":
         return HostList(
@@ -1385,7 +1477,10 @@ class GroupConfigList(BaseAPIListObject):
 def new_group_config(api, **args) -> "GroupConfig":
     """Create new 'GroupConfig' and return it"""
     endpoint = getattr(api.objects, 'group-config')
-    group = endpoint.create(**args)
+    try:
+        group = endpoint.create(**args)
+    except AttributeError as error:
+        raise NoSuchEndpointOrAccessIsDenied from error
     return GroupConfig(api, id=group['id'])
 
 
@@ -1444,6 +1539,211 @@ class ConcernList(BaseAPIListObject):
     _ENTRY_CLASS = Concern
 
 
+##################################################
+#              U S E R
+##################################################
+class User(BaseAPIObject):
+    IDNAME = 'id'
+    PATH = ['rbac', 'user']
+    FILTERS = ['id', 'username', 'first_name', 'last_name', 'email', 'is_superuser', 'group']
+    id = None
+    username = None
+    first_name = None
+    last_name = None
+    email = None
+    is_superuser = None
+    password = None
+    profile = None
+
+    def group_list(self) -> "GroupList":
+        """Return list of `Group` object"""
+        # TODO: I can't do this, because search() is not working
+        # return GroupList(self._api, user=self.id)
+        groups = GroupList(self._api)
+        data = []
+        for group in self._data['group']:
+            data.append(Group(self._api, id=group['id']))
+        groups.data = data
+        return groups
+
+    def change_password(self, password: str) -> None:
+        """Changing user password"""
+        try:
+            self._api.objects.rbac.user.partial_update(id=self.id, password=password)
+        except AttributeError as error:
+            raise NoSuchEndpointOrAccessIsDenied from error
+        self.reread()
+
+
+class UserList(BaseAPIListObject):
+    """List of `User` objects"""
+
+    _ENTRY_CLASS = User
+
+
+@allure_step('Create user {username}')
+def new_user(api: ADCMApiWrapper, username: str, password: str, **kwargs):
+    """Create new `User` object"""
+    try:
+        user = api.objects.rbac.user.create(
+            username=username, password=password, **strip_none_keys(kwargs)
+        )
+    except AttributeError as error:
+        raise NoSuchEndpointOrAccessIsDenied from error
+    return User(api, id=user['id'])
+
+
+##################################################
+#              G R O U P
+##################################################
+class Group(BaseAPIObject):
+    IDNAME = 'id'
+    PATH = ['rbac', 'group']
+    FILTERS = ['id', 'name', 'group']
+    id = None
+    name = None
+    description = None
+
+    def user_list(self) -> "UserList":
+        # TODO: I can't do this, because search() is not working
+        # return UserList(self._api, group=self.id)
+        users = UserList(self._api)
+        data = []
+        for user in self._data['user']:
+            data.append(User(self._api, id=user['id']))
+        users.data = data
+        return users
+
+    def add_user(self, user: User) -> None:
+        """Adding a user to a group"""
+        current_users = self.user_list()
+        users = [{'id': obj.id} for obj in current_users]
+        users.append({'id': user.id})
+        try:
+            self._api.objects.rbac.group.partial_update(id=self.id, user=users)
+        except AttributeError as error:
+            raise NoSuchEndpointOrAccessIsDenied from error
+        user.reread()
+        self.reread()
+
+
+class GroupList(BaseAPIListObject):
+    _ENTRY_CLASS = Group
+
+
+@allure_step('Create group {name}')
+def new_group(api: ADCMApiWrapper, name: str, **kwargs):
+    """Create new `Group` object"""
+    try:
+        group = api.objects.rbac.group.create(name=name, **strip_none_keys(kwargs))
+    except AttributeError as error:
+        raise NoSuchEndpointOrAccessIsDenied from error
+    return Group(api, id=group['id'])
+
+
+##################################################
+#              R O L E
+##################################################
+class Role(BaseAPIObject):
+    IDNAME = 'id'
+    PATH = ['rbac', 'role']
+    FILTERS = ['id', 'name', 'display_name', 'built_in', 'type', 'child']
+    id = None
+    name = None
+    display_name = None
+    description = None
+    built_in = None
+    type = None
+    category = None
+    parametrized_by_type = None
+
+    def child_list(self) -> "RoleList":
+        # TODO: I can't do this, because search() is not working
+        # return RoleList(self._api, child=self.id)
+        roles = RoleList(self._api)
+        data = []
+        for role in self._data['child']:
+            data.append(Role(self._api, id=role['id']))
+        roles.data = data
+        return roles
+
+
+class RoleList(BaseAPIListObject):
+    _ENTRY_CLASS = Role
+
+
+@allure_step('Create role {name}')
+def new_role(api: ADCMApiWrapper, name: str, **kwargs):
+    """Create new `Role` object"""
+    try:
+        role = api.objects.rbac.role.create(name=name, **strip_none_keys(kwargs))
+    except AttributeError as error:
+        raise NoSuchEndpointOrAccessIsDenied from error
+    return Role(api, id=role['id'])
+
+
+##################################################
+#              P O L I C Y
+##################################################
+class Policy(BaseAPIObject):
+    IDNAME = 'id'
+    PATH = ['rbac', 'policy']
+    FILTERS = ['id', 'name', 'built_in', 'role', 'user', 'group']
+    id = None
+    name = None
+    built_in = None
+
+    def object_list(self) -> "List[Union[Cluster, Service, Component, Provider, Host]]":
+        data = []
+        for obj in self._data['object']:
+            data.append(TASK_PARENT[obj['type']](self._api, id=obj['id']))
+        return data
+
+    def role(self) -> "Role":
+        return Role(self._api, id=self._data['role']['id'])
+
+    def user_list(self) -> "UserList":
+        users = UserList(self._api)
+        data = []
+        for user in self._data['user']:
+            data.append(User(self._api, id=user['id']))
+        users.data = data
+        return users
+
+    def group_list(self) -> "GroupList":
+        groups = GroupList(self._api)
+        data = []
+        for group in self._data['group']:
+            data.append(Group(self._api, id=group['id']))
+        groups.data = data
+        return groups
+
+
+class PolicyList(BaseAPIListObject):
+    _ENTRY_CLASS = Policy
+
+
+@allure_step('Create policy {name}')
+def new_policy(
+    api: ADCMApiWrapper,
+    name: str,
+    role: Role,
+    user: UserList,
+    group: GroupList = None,
+    objects: List[Union[Cluster, Service, Component, Provider, Host]] = None,
+):
+    users = [{'id': obj.id} for obj in user]
+    groups = [{'id': obj.id} for obj in group or []]
+    objects = [{'id': obj.id, 'type': obj.prototype().type} for obj in objects or []]
+    try:
+        policy = api.objects.rbac.policy.create(
+            name=name, role={'id': role.id}, user=users, group=groups, object=objects
+        )
+    except AttributeError as error:
+        raise NoSuchEndpointOrAccessIsDenied from error
+    return Policy(api, id=policy['id'])
+
+
 ##################################################
 #              C L I E N T
 ##################################################
@@ -1461,7 +1761,7 @@ class ADCMClient:
             self._api = ADCMApiWrapper(self.url)
             self.auth(user, password)
 
-        if self.api_token() is not None:
+        if self.api_token() is not None and user == 'admin':
             self.guess_adcm_url()
 
         self.adcm_version = self._api.adcm_version
@@ -1609,14 +1909,20 @@ class ADCMClient:
 
     def _upload(self, bundle_stream: BytesIO) -> Bundle:
         """Upload and create Bundle from file={bundle_stream}"""
-        self._api.objects.stack.upload.create(file=bundle_stream)
+        try:
+            self._api.objects.stack.upload.create(file=bundle_stream)
+        except AttributeError as error:
+            raise NoSuchEndpointOrAccessIsDenied from error
         bundle_stream.seek(0)
         allure_attach(
             body=bundle_stream.getvalue(),
             name="bundle.tgz",
             extension="tgz",
         )
-        data = self._api.objects.stack.load.create(bundle_file="file")
+        try:
+            data = self._api.objects.stack.load.create(bundle_file="file")
+        except AttributeError as error:
+            raise NoSuchEndpointOrAccessIsDenied from error
         bundle_stream.close()
         return self.bundle(bundle_id=data['id'])
 
@@ -1651,7 +1957,10 @@ class ADCMClient:
         """Delete bundle object"""
         bundle = self.bundle(**args)
         with allure_step(f"Delete bundle {bundle.name}"):
-            self._api.objects.stack.bundle.delete(bundle_id=bundle.bundle_id)
+            try:
+                self._api.objects.stack.bundle.delete(bundle_id=bundle.bundle_id)
+            except AttributeError as error:
+                raise NoSuchEndpointOrAccessIsDenied from error
 
     def group_config(self, **kwargs) -> GroupConfig:
         """Return 'GroupConfig object'"""
@@ -1660,3 +1969,73 @@ class ADCMClient:
     def group_config_list(self, paging=None, **kwargs) -> GroupConfigList:
         """Return list of 'GroupConfig' objects"""
         return GroupConfigList(self._api, paging=paging, **kwargs)
+
+    @min_server_version('2022.01.31.00')
+    def me(self) -> "Me":
+        return Me(**self._api.action(['rbac', 'me', 'read']))
+
+    @min_server_version('2022.01.31.00')
+    def user_create(self, username: str, password: str, **kwargs) -> "User":
+        """Create `User` object"""
+        return new_user(self._api, username, password, **kwargs)
+
+    @min_server_version('2022.01.31.00')
+    def user(self, **kwargs) -> "User":
+        """Return `User` object"""
+        return User(self._api, **kwargs)
+
+    @min_server_version('2022.01.31.00')
+    def user_list(self, paging=None, **kwargs) -> "UserList":
+        """Return list of `User` objects"""
+        return UserList(self._api, paging=paging, **kwargs)
+
+    @min_server_version('2022.01.31.00')
+    def group_create(self, name: str, **kwargs) -> "Group":
+        """Create `Group` object"""
+        return new_group(self._api, name, **kwargs)
+
+    @min_server_version('2022.01.31.00')
+    def group(self, **kwargs) -> "Group":
+        return Group(self._api, **kwargs)
+
+    @min_server_version('2022.01.31.00')
+    def group_list(self, paging=None, **kwargs) -> "GroupList":
+        """Return list of `Group` object"""
+        return GroupList(self._api, paging=paging, **kwargs)
+
+    @min_server_version('2022.01.31.00')
+    def role_create(self, name: str, **kwargs) -> "Role":
+        """Create new `Role` object"""
+        return new_role(self._api, name, **kwargs)
+
+    @min_server_version('2022.01.31.00')
+    def role(self, **kwargs) -> "Role":
+        """Return `Role` object"""
+        return Role(self._api, **kwargs)
+
+    @min_server_version('2022.01.31.00')
+    def role_list(self, paging=None, **kwargs) -> "RoleList":
+        """Return list of `Role` objects"""
+        return RoleList(self._api, paging=paging, **kwargs)
+
+    @min_server_version('2022.01.31.00')
+    def policy_create(
+        self,
+        name: str,
+        role: Role,
+        user: Union[UserList, List[User]],
+        group: Union[GroupList, List[Group]] = None,
+        objects: List[Union[Cluster, Service, Component, Provider, Host]] = None,
+    ) -> "Policy":
+        """Create `Policy` object"""
+        return new_policy(self._api, name, role, user, group, objects)
+
+    @min_server_version('2022.01.31.00')
+    def policy(self, **kwargs) -> "Policy":
+        """Return `Policy` object"""
+        return Policy(self._api, **kwargs)
+
+    @min_server_version('2022.01.31.00')
+    def policy_list(self, paging=None, **kwargs) -> "PolicyList":
+        """Return list if `Policy` objects"""
+        return PolicyList(self._api, paging=paging, **kwargs)
